pecos.foreign\_objects
======================

.. automodule:: pecos.foreign_objects



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.foreign_objects.foreign_object_abc
   pecos.foreign_objects.object_pool
   pecos.foreign_objects.python
   pecos.foreign_objects.wasm_execution_timer_thread
   pecos.foreign_objects.wasmer
   pecos.foreign_objects.wasmtime
